/* media-manager.c generated by valac 0.20.1.2-ca5c2, the Vala compiler
 * generated from media-manager.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gudev/gudev.h>
#include <libtracker-sparql/tracker-sparql.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libcommon.h>
#include <gtk/gtk.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesMediaManagerPrivate BoxesMediaManagerPrivate;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesMediaManagerCreateInstallerMediaForPathData BoxesMediaManagerCreateInstallerMediaForPathData;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesMediaManagerCreateInstallerMediaFromConfigData BoxesMediaManagerCreateInstallerMediaFromConfigData;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesMediaManagerListInstallerMediasData BoxesMediaManagerListInstallerMediasData;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesMediaManagerCreateInstallerMediaFromIsoInfoData BoxesMediaManagerCreateInstallerMediaFromIsoInfoData;

struct _BoxesMediaManager {
	GObject parent_instance;
	BoxesMediaManagerPrivate * priv;
};

struct _BoxesMediaManagerClass {
	GObjectClass parent_class;
};

struct _BoxesMediaManagerPrivate {
	BoxesOSDatabase* _os_db;
	GUdevClient* _client;
	TrackerSparqlConnection* connection;
};

struct _BoxesMediaManagerCreateInstallerMediaForPathData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	gchar* path;
	GCancellable* cancellable;
	BoxesInstallerMedia* result;
	const gchar* _tmp0_;
	GCancellable* _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp3_;
	BoxesInstallerMedia* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesMediaManagerCreateInstallerMediaFromConfigData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	GVirConfigDomain* config;
	BoxesInstallerMedia* result;
	GVirConfigDomain* _tmp0_;
	gchar* _tmp1_;
	gchar* path;
	GVirConfigDomain* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* label;
	OsinfoOs* os;
	OsinfoMedia* os_media;
	const gchar* _tmp6_;
	GVirConfigDomain* _tmp7_;
	gchar* _tmp8_;
	gchar* os_id;
	const gchar* _tmp9_;
	BoxesOSDatabase* _tmp10_;
	const gchar* _tmp11_;
	OsinfoOs* _tmp12_;
	OsinfoOs* _tmp13_;
	GVirConfigDomain* _tmp14_;
	gchar* _tmp15_;
	gchar* media_id;
	const gchar* _tmp16_;
	BoxesOSDatabase* _tmp17_;
	OsinfoOs* _tmp18_;
	const gchar* _tmp19_;
	OsinfoMedia* _tmp20_;
	OsinfoMedia* _tmp21_;
	GError* _error_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	OsinfoMedia* _tmp25_;
	OsinfoMedia* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* architecture;
	BoxesOSDatabase* _tmp31_;
	OsinfoOs* _tmp32_;
	const gchar* _tmp33_;
	OsinfoResources* _tmp34_;
	OsinfoResources* resources;
	const gchar* _tmp35_;
	const gchar* _tmp36_;
	OsinfoOs* _tmp37_;
	OsinfoMedia* _tmp38_;
	OsinfoResources* _tmp39_;
	BoxesInstallerMedia* _tmp40_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp41_;
	BoxesInstallerMedia* _tmp42_;
	BoxesInstallerMedia* _tmp43_;
	BoxesInstallerMedia* _tmp44_;
	GError* _vala1__error_;
	GError* _tmp45_;
	const gchar* _tmp46_;
	GError * _inner_error_;
};

struct _BoxesMediaManagerListInstallerMediasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	GList* result;
	GList* list;
	GUdevClient* _tmp0_;
	GUdevEnumerator* _tmp1_;
	GUdevEnumerator* enumerator;
	GUdevEnumerator* _tmp2_;
	GUdevEnumerator* _tmp3_;
	GList* _tmp4_;
	GList* device_collection;
	GList* device_it;
	GUdevDevice* _tmp5_;
	GUdevDevice* device;
	gboolean _tmp6_;
	GUdevDevice* _tmp7_;
	const gchar* _tmp8_;
	GUdevDevice* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	GUdevDevice* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* path;
	const gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	GError* _error_;
	const gchar* _tmp19_;
	GError* _tmp20_;
	const gchar* _tmp21_;
	TrackerSparqlConnection* _tmp22_;
	TrackerSparqlConnection* _tmp23_;
	TrackerSparqlCursor* _tmp24_;
	TrackerSparqlCursor* cursor;
	TrackerSparqlCursor* _tmp25_;
	gboolean _tmp26_;
	gboolean _tmp27_;
	TrackerSparqlCursor* _tmp28_;
	const gchar* _tmp29_;
	GFile* _tmp30_;
	GFile* file;
	GFile* _tmp31_;
	gchar* _tmp32_;
	gchar* _vala1_path;
	const gchar* _tmp33_;
	TrackerSparqlCursor* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* title;
	TrackerSparqlCursor* _tmp37_;
	const gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* os_id;
	TrackerSparqlCursor* _tmp40_;
	const gchar* _tmp41_;
	gchar* _tmp42_;
	gchar* media_id;
	const gchar* _tmp43_;
	const gchar* _tmp44_;
	const gchar* _tmp45_;
	const gchar* _tmp46_;
	BoxesInstallerMedia* _tmp47_;
	BoxesInstallerMedia* _vala1_media;
	BoxesInstallerMedia* _tmp48_;
	BoxesInstallerMedia* _tmp49_;
	GError* _vala1__error_;
	const gchar* _tmp50_;
	GError* _tmp51_;
	const gchar* _tmp52_;
	GError* _vala2__error_;
	GError* _tmp53_;
	const gchar* _tmp54_;
	GError * _inner_error_;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
	OsinfoDeviceList* supported_devices;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
};

struct _BoxesMediaManagerCreateInstallerMediaFromIsoInfoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	gchar* path;
	gchar* label;
	gchar* os_id;
	gchar* media_id;
	BoxesInstallerMedia* result;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GError* _tmp6_;
	GError* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	const gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesInstallerMedia* _tmp17_;
	BoxesOSDatabase* _tmp18_;
	const gchar* _tmp19_;
	OsinfoOs* _tmp20_;
	OsinfoOs* os;
	BoxesOSDatabase* _tmp21_;
	OsinfoOs* _tmp22_;
	const gchar* _tmp23_;
	OsinfoMedia* _tmp24_;
	OsinfoMedia* os_media;
	BoxesOSDatabase* _tmp25_;
	OsinfoOs* _tmp26_;
	OsinfoMedia* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	OsinfoResources* _tmp31_;
	OsinfoResources* _tmp32_;
	OsinfoResources* resources;
	const gchar* _tmp33_;
	const gchar* _tmp34_;
	OsinfoOs* _tmp35_;
	OsinfoMedia* _tmp36_;
	OsinfoResources* _tmp37_;
	BoxesInstallerMedia* _tmp38_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp39_;
	BoxesInstallerMedia* _tmp40_;
	BoxesInstallerMedia* _tmp41_;
	GError * _inner_error_;
};

typedef void (*BoxesMediaManagerInstallerRecognized) (OsinfoMedia* os_media, OsinfoOs* os, void* user_data);

static gpointer boxes_media_manager_parent_class = NULL;
static BoxesMediaManager* boxes_media_manager_media_manager;
static BoxesMediaManager* boxes_media_manager_media_manager = NULL;

GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_os_database_get_type (void) G_GNUC_CONST;
#define BOXES_MEDIA_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerPrivate))
enum  {
	BOXES_MEDIA_MANAGER_DUMMY_PROPERTY,
	BOXES_MEDIA_MANAGER_OS_DB,
	BOXES_MEDIA_MANAGER_CLIENT
};
#define BOXES_MEDIA_MANAGER_SPARQL_QUERY "SELECT nie:url(?iso) nie:title(?iso) osinfo:id(?iso) osinfo:mediaId(?i" \
"so)" " { ?iso nfo:isBootable true }"
BoxesMediaManager* boxes_media_manager_get_instance (void);
static BoxesMediaManager* boxes_media_manager_new (void);
static BoxesMediaManager* boxes_media_manager_construct (GType object_type);
static void boxes_media_manager_create_installer_media_for_path_data_free (gpointer _data);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_media_manager_create_installer_media_for_path_co (BoxesMediaManagerCreateInstallerMediaForPathData* _data_);
void boxes_installer_media_new_for_path (const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_new_for_path_finish (GAsyncResult* _res_, GError** error);
void boxes_installer_media_construct_for_path (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_construct_for_path_finish (GAsyncResult* _res_, GError** error);
static void boxes_media_manager_create_installer_media_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
static void boxes_media_manager_create_installer_media_from_config_data_free (gpointer _data);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static gboolean boxes_media_manager_create_installer_media_from_config_co (BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_);
gchar* boxes_vm_configurator_get_source_media_path (GVirConfigDomain* domain);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_media_manager_create_installer_media_from_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gchar* boxes_vm_configurator_get_os_media_id (GVirConfigDomain* domain);
OsinfoMedia* boxes_os_database_get_media_by_id (BoxesOSDatabase* self, OsinfoOs* os, const gchar* id, GError** error);
OsinfoResources* boxes_os_database_get_resources_for_os (BoxesOSDatabase* self, OsinfoOs* os, const gchar* architecture);
BoxesInstallerMedia* boxes_installer_media_new_from_iso_info (const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
BoxesInstallerMedia* boxes_installer_media_construct_from_iso_info (GType object_type, const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_media_manager_list_installer_medias_data_free (gpointer _data);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static gboolean boxes_media_manager_list_installer_medias_co (BoxesMediaManagerListInstallerMediasData* _data_);
GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self);
static void boxes_media_manager_list_installer_medias_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_media_manager_create_installer_media_from_iso_info (BoxesMediaManager* self, const gchar* path, const gchar* label, const gchar* os_id, const gchar* media_id, GAsyncReadyCallback _callback_, gpointer _user_data_);
static BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_iso_info_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static gint boxes_media_manager_compare_media (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b);
static gint _boxes_media_manager_compare_media_gcompare_func (gconstpointer a, gconstpointer b);
BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
static void boxes_media_manager_set_client (BoxesMediaManager* self, GUdevClient* value);
BoxesOSDatabase* boxes_os_database_new (void);
BoxesOSDatabase* boxes_os_database_construct (GType object_type);
static void boxes_media_manager_set_os_db (BoxesMediaManager* self, BoxesOSDatabase* value);
void boxes_os_database_load (BoxesOSDatabase* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_os_database_load_finish (BoxesOSDatabase* self, GAsyncResult* _res_);
static void boxes_media_manager_create_installer_media_from_iso_info_data_free (gpointer _data);
static gboolean boxes_media_manager_create_installer_media_from_iso_info_co (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_);
static void boxes_media_manager_create_installer_media_from_iso_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_media_manager_finalize (GObject* obj);
static void _vala_boxes_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return self ? g_object_ref (self) : NULL;
#line 433 "media-manager.c"
}


BoxesMediaManager* boxes_media_manager_get_instance (void) {
	BoxesMediaManager* result = NULL;
	BoxesMediaManager* _tmp0_;
	BoxesMediaManager* _tmp2_;
	BoxesMediaManager* _tmp3_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = boxes_media_manager_media_manager;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_tmp0_ == NULL) {
#line 446 "media-manager.c"
		BoxesMediaManager* _tmp1_;
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp1_ = boxes_media_manager_new ();
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (boxes_media_manager_media_manager);
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_media_manager = _tmp1_;
#line 454 "media-manager.c"
	}
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = boxes_media_manager_media_manager;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _tmp3_;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 464 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_for_path_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
	_data_ = _data;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaForPathData, _data_);
#line 481 "media-manager.c"
}


void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
	BoxesMediaManager* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	GCancellable* _tmp3_;
	GCancellable* _tmp4_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaForPathData);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_for_path);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_for_path_data_free);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = path;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->path = _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp3_ = cancellable;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->cancellable = _tmp4_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_for_path_co (_data_);
#line 520 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 531 "media-manager.c"
	}
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 541 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_for_path_co (_data_);
#line 555 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_for_path_co (BoxesMediaManagerCreateInstallerMediaForPathData* _data_) {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 0:
#line 564 "media-manager.c"
		goto _state_0;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 1:
#line 568 "media-manager.c"
		goto _state_1;
		default:
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 573 "media-manager.c"
	}
	_state_0:
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->path;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = _data_->cancellable;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_state_ = 1;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_installer_media_new_for_path (_data_->_tmp0_, _data_->self, _data_->_tmp1_, boxes_media_manager_create_installer_media_for_path_ready, _data_);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 586 "media-manager.c"
	_state_1:
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = boxes_installer_media_new_for_path_finish (_data_->_res_, &_data_->_inner_error_);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp2_;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 602 "media-manager.c"
		} else {
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 606 "media-manager.c"
		}
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 612 "media-manager.c"
	}
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = _data_->media;
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = NULL;
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp3_, &_data_->_inner_error_);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 634 "media-manager.c"
		} else {
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 638 "media-manager.c"
		}
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 644 "media-manager.c"
	}
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->_tmp5_;
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 654 "media-manager.c"
	} else {
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 658 "media-manager.c"
	}
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 670 "media-manager.c"
	} else {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 674 "media-manager.c"
	}
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 680 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_config_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
	_data_ = _data;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->config);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaFromConfigData, _data_);
#line 695 "media-manager.c"
}


void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
	BoxesMediaManager* _tmp0_;
	GVirConfigDomain* _tmp1_;
	GVirConfigDomain* _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaFromConfigData);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_from_config);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_from_config_data_free);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = config;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->config);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->config = _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_config_co (_data_);
#line 724 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 739 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_config_co (_data_);
#line 753 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_from_config_co (BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_) {
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 0:
#line 762 "media-manager.c"
		goto _state_0;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 1:
#line 766 "media-manager.c"
		goto _state_1;
		default:
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 771 "media-manager.c"
	}
	_state_0:
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->config;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = NULL;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = boxes_vm_configurator_get_source_media_path (_data_->_tmp0_);
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->path = _data_->_tmp1_;
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = _data_->config;
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = gvir_config_domain_get_title (_data_->_tmp2_);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp5_ = g_strdup (_data_->_tmp4_);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->label = _data_->_tmp5_;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->os = NULL;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->os_media = NULL;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp6_ = _data_->path;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp6_ == NULL) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->result = NULL;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 814 "media-manager.c"
		} else {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 818 "media-manager.c"
		}
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 824 "media-manager.c"
	}
	{
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = _data_->config;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = NULL;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = boxes_vm_configurator_get_os_id (_data_->_tmp7_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->os_id = _data_->_tmp8_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = _data_->os_id;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_tmp9_ != NULL) {
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp10_ = _data_->self->priv->_os_db;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp11_ = _data_->os_id;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 1;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			boxes_os_database_get_os_by_id (_data_->_tmp10_, _data_->_tmp11_, boxes_media_manager_create_installer_media_from_config_ready, _data_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 849 "media-manager.c"
			_state_1:
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp12_ = NULL;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp12_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp10_, _data_->_res_, &_data_->_inner_error_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp13_ = _data_->_tmp12_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 863 "media-manager.c"
					goto __catch54_boxes_os_database_error;
				}
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os_media);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->label);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				g_clear_error (&_data_->_inner_error_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 882 "media-manager.c"
			}
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->os);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->os = _data_->_tmp13_;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp14_ = _data_->config;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp15_ = NULL;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp15_ = boxes_vm_configurator_get_os_media_id (_data_->_tmp14_);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->media_id = _data_->_tmp15_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp16_ = _data_->media_id;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (_data_->_tmp16_ != NULL) {
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp17_ = _data_->self->priv->_os_db;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp18_ = _data_->os;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp19_ = _data_->media_id;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp20_ = NULL;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp20_ = boxes_os_database_get_media_by_id (_data_->_tmp17_, _data_->_tmp18_, _data_->_tmp19_, &_data_->_inner_error_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_ != NULL) {
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->media_id);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->os_id);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 920 "media-manager.c"
						goto __catch54_boxes_os_database_error;
					}
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->media_id);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->os_id);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->os_media);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->os);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->label);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->path);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					g_clear_error (&_data_->_inner_error_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 941 "media-manager.c"
				}
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os_media);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->os_media = _data_->_tmp21_;
#line 947 "media-manager.c"
			}
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->media_id);
#line 951 "media-manager.c"
		}
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->os_id);
#line 955 "media-manager.c"
	}
	goto __finally54;
	__catch54_boxes_os_database_error:
	{
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp22_ = _data_->_error_;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_warning ("media-manager.vala:53: %s", _data_->_tmp23_);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_error_);
#line 972 "media-manager.c"
	}
	__finally54:
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 991 "media-manager.c"
	}
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp25_ = _data_->os_media;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp25_ != NULL) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp26_ = _data_->os_media;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp27_ = NULL;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_get (_data_->_tmp26_, "architecture", &_data_->_tmp27_, NULL);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp24_);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = _data_->_tmp28_;
#line 1009 "media-manager.c"
	} else {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp24_);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = NULL;
#line 1015 "media-manager.c"
	}
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp29_ = _data_->_tmp24_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp30_ = g_strdup (_data_->_tmp29_);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->architecture = _data_->_tmp30_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = _data_->self->priv->_os_db;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = _data_->os;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp33_ = _data_->architecture;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = NULL;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = boxes_os_database_get_resources_for_os (_data_->_tmp31_, _data_->_tmp32_, _data_->_tmp33_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->resources = _data_->_tmp34_;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp35_ = _data_->path;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = _data_->label;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = _data_->os;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = _data_->os_media;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = _data_->resources;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = boxes_installer_media_new_from_iso_info (_data_->_tmp35_, _data_->_tmp36_, _data_->_tmp37_, _data_->_tmp38_, _data_->_tmp39_);
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp40_;
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = _data_->media;
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (_data_->_tmp41_ != NULL, NULL);
#line 1053 "media-manager.c"
	{
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp42_ = _data_->media;
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp43_ = NULL;
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp43_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp42_, &_data_->_inner_error_);
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp44_ = _data_->_tmp43_;
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1065 "media-manager.c"
			goto __catch55_g_error;
		}
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->media = _data_->_tmp44_;
#line 1072 "media-manager.c"
	}
	goto __finally55;
	__catch55_g_error:
	{
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp45_ = _data_->_vala1__error_;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp46_ = _data_->_tmp45_->message;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_debug ("media-manager.vala:65: %s", _data_->_tmp46_);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 1089 "media-manager.c"
	}
	__finally55:
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->resources);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->architecture);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp24_);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1116 "media-manager.c"
	}
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->media;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->architecture);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp24_);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1138 "media-manager.c"
	} else {
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1142 "media-manager.c"
	}
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->architecture);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp24_);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1168 "media-manager.c"
	} else {
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1172 "media-manager.c"
	}
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 1178 "media-manager.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1185 "media-manager.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_list_free (self);
#line 1194 "media-manager.c"
}


static void boxes_media_manager_list_installer_medias_data_free (gpointer _data) {
	BoxesMediaManagerListInstallerMediasData* _data_;
	_data_ = _data;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	__g_list_free__g_object_unref0_0 (_data_->result);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerListInstallerMediasData, _data_);
#line 1207 "media-manager.c"
}


void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerListInstallerMediasData* _data_;
	BoxesMediaManager* _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerListInstallerMediasData);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_list_installer_medias);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_list_installer_medias_data_free);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_list_installer_medias_co (_data_);
#line 1226 "media-manager.c"
}


GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_) {
	GList* result;
	BoxesMediaManagerListInstallerMediasData* _data_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 1241 "media-manager.c"
}


static void boxes_media_manager_list_installer_medias_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerListInstallerMediasData* _data_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_list_installer_medias_co (_data_);
#line 1255 "media-manager.c"
}


static gint _boxes_media_manager_compare_media_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = boxes_media_manager_compare_media (a, b);
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 1264 "media-manager.c"
}


static gboolean boxes_media_manager_list_installer_medias_co (BoxesMediaManagerListInstallerMediasData* _data_) {
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 0:
#line 1273 "media-manager.c"
		goto _state_0;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 1:
#line 1277 "media-manager.c"
		goto _state_1;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 2:
#line 1281 "media-manager.c"
		goto _state_2;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 3:
#line 1285 "media-manager.c"
		goto _state_3;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 4:
#line 1289 "media-manager.c"
		goto _state_4;
		default:
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 1294 "media-manager.c"
	}
	_state_0:
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->list = NULL;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->self->priv->_client;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = g_udev_enumerator_new (_data_->_tmp0_);
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->enumerator = _data_->_tmp1_;
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = _data_->enumerator;
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_udev_enumerator_add_match_property (_data_->_tmp2_, "DEVTYPE", "disk");
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = _data_->enumerator;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = NULL;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = g_udev_enumerator_execute (_data_->_tmp3_);
#line 1315 "media-manager.c"
	{
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->device_collection = _data_->_tmp4_;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		for (_data_->device_it = _data_->device_collection; _data_->device_it != NULL; _data_->device_it = _data_->device_it->next) {
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = _g_object_ref0 ((GUdevDevice*) _data_->device_it->data);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->device = _data_->_tmp5_;
#line 1325 "media-manager.c"
			{
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp7_ = _data_->device;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp8_ = NULL;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp8_ = g_udev_device_get_property (_data_->_tmp7_, "ID_FS_BOOT_SYSTEM_ID");
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp8_ == NULL) {
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp9_ = _data_->device;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp10_ = FALSE;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp10_ = g_udev_device_get_property_as_boolean (_data_->_tmp9_, "OSINFO_BOOTABLE");
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp6_ = !_data_->_tmp10_;
#line 1343 "media-manager.c"
				} else {
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp6_ = FALSE;
#line 1347 "media-manager.c"
				}
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp11_ = _data_->_tmp6_;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp11_) {
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->device);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					continue;
#line 1357 "media-manager.c"
				}
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp12_ = _data_->device;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp13_ = NULL;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp13_ = g_udev_device_get_device_file (_data_->_tmp12_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = g_strdup (_data_->_tmp13_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->path = _data_->_tmp14_;
#line 1369 "media-manager.c"
				{
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp15_ = _data_->path;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_state_ = 1;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					boxes_media_manager_create_installer_media_for_path (_data_->self, _data_->_tmp15_, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1379 "media-manager.c"
					_state_1:
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp16_ = NULL;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp16_ = boxes_media_manager_create_installer_media_for_path_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->media = _data_->_tmp16_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					if (_data_->_inner_error_ != NULL) {
#line 1389 "media-manager.c"
						goto __catch56_g_error;
					}
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp17_ = _data_->media;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp18_ = _g_object_ref0 (_data_->_tmp17_);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->list = g_list_append (_data_->list, _data_->_tmp18_);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->media);
#line 1400 "media-manager.c"
				}
				goto __finally56;
				__catch56_g_error:
				{
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_inner_error_ = NULL;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp19_ = _data_->path;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp20_ = _data_->_error_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_data_->_tmp21_ = _data_->_tmp20_->message;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					g_warning ("media-manager.vala:90: Failed to get information on device '%s': %s. I" \
"gnoring..", _data_->_tmp19_, _data_->_tmp21_);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_error_free0 (_data_->_error_);
#line 1419 "media-manager.c"
				}
				__finally56:
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_ != NULL) {
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->path);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->device);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					__g_list_free__g_object_unref0_0 (_data_->device_collection);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->enumerator);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					__g_list_free__g_object_unref0_0 (_data_->list);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					g_clear_error (&_data_->_inner_error_);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1440 "media-manager.c"
				}
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->device);
#line 1446 "media-manager.c"
			}
		}
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		__g_list_free__g_object_unref0_0 (_data_->device_collection);
#line 1451 "media-manager.c"
	}
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = _data_->self->priv->connection;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp22_ == NULL) {
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->result = _data_->list;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->enumerator);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1465 "media-manager.c"
		} else {
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1469 "media-manager.c"
		}
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1475 "media-manager.c"
	}
	{
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp23_ = _data_->self->priv->connection;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 2;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		tracker_sparql_connection_query_async (_data_->_tmp23_, BOXES_MEDIA_MANAGER_SPARQL_QUERY, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1486 "media-manager.c"
		_state_2:
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = NULL;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = tracker_sparql_connection_query_finish (_data_->_tmp23_, _data_->_res_, &_data_->_inner_error_);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->cursor = _data_->_tmp24_;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1496 "media-manager.c"
			goto __catch57_g_error;
		}
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		while (TRUE) {
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp25_ = _data_->cursor;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 3;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			tracker_sparql_cursor_next_async (_data_->_tmp25_, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1509 "media-manager.c"
			_state_3:
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp26_ = FALSE;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp26_ = tracker_sparql_cursor_next_finish (_data_->_tmp25_, _data_->_res_, &_data_->_inner_error_);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = _data_->_tmp26_;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->cursor);
#line 1521 "media-manager.c"
				goto __catch57_g_error;
			}
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (!_data_->_tmp27_) {
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				break;
#line 1528 "media-manager.c"
			}
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp28_ = _data_->cursor;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp29_ = NULL;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp29_ = tracker_sparql_cursor_get_string (_data_->_tmp28_, 0, NULL);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp30_ = NULL;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp30_ = g_file_new_for_uri (_data_->_tmp29_);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->file = _data_->_tmp30_;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp31_ = _data_->file;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp32_ = NULL;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp32_ = g_file_get_path (_data_->_tmp31_);
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_vala1_path = _data_->_tmp32_;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp33_ = _data_->_vala1_path;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (_data_->_tmp33_ == NULL) {
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->_vala1_path);
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->file);
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				continue;
#line 1560 "media-manager.c"
			}
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp34_ = _data_->cursor;
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp35_ = NULL;
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp35_ = tracker_sparql_cursor_get_string (_data_->_tmp34_, 1, NULL);
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp36_ = g_strdup (_data_->_tmp35_);
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->title = _data_->_tmp36_;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp37_ = _data_->cursor;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp38_ = NULL;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp38_ = tracker_sparql_cursor_get_string (_data_->_tmp37_, 2, NULL);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp39_ = g_strdup (_data_->_tmp38_);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->os_id = _data_->_tmp39_;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp40_ = _data_->cursor;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp41_ = NULL;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp41_ = tracker_sparql_cursor_get_string (_data_->_tmp40_, 3, NULL);
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->_tmp42_ = g_strdup (_data_->_tmp41_);
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_data_->media_id = _data_->_tmp42_;
#line 1592 "media-manager.c"
			{
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp43_ = _data_->_vala1_path;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp44_ = _data_->title;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp45_ = _data_->os_id;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp46_ = _data_->media_id;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_state_ = 4;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				boxes_media_manager_create_installer_media_from_iso_info (_data_->self, _data_->_tmp43_, _data_->_tmp44_, _data_->_tmp45_, _data_->_tmp46_, boxes_media_manager_list_installer_medias_ready, _data_);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 1608 "media-manager.c"
				_state_4:
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47_ = NULL;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47_ = boxes_media_manager_create_installer_media_from_iso_info_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_vala1_media = _data_->_tmp47_;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_ != NULL) {
#line 1618 "media-manager.c"
					goto __catch58_g_error;
				}
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp48_ = _data_->_vala1_media;
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp49_ = _g_object_ref0 (_data_->_tmp48_);
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->list = g_list_insert_sorted (_data_->list, _data_->_tmp49_, _boxes_media_manager_compare_media_gcompare_func);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 1629 "media-manager.c"
			}
			goto __finally58;
			__catch58_g_error:
			{
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_inner_error_ = NULL;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp50_ = _data_->_vala1_path;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp51_ = _data_->_vala1__error_;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_data_->_tmp52_ = _data_->_tmp51_->message;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				g_warning ("media-manager.vala:114: Failed to use ISO '%s': %s", _data_->_tmp50_, _data_->_tmp52_);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 1648 "media-manager.c"
			}
			__finally58:
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->media_id);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->title);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->_vala1_path);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->file);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->cursor);
#line 1665 "media-manager.c"
				goto __catch57_g_error;
			}
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->media_id);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->os_id);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->title);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->_vala1_path);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->file);
#line 1678 "media-manager.c"
		}
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->cursor);
#line 1682 "media-manager.c"
	}
	goto __finally57;
	__catch57_g_error:
	{
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_vala2__error_ = _data_->_inner_error_;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp53_ = _data_->_vala2__error_;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp54_ = _data_->_tmp53_->message;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_warning ("media-manager.vala:118: Failed to fetch list of ISOs from Tracker: %s.", _data_->_tmp54_);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala2__error_);
#line 1699 "media-manager.c"
	}
	__finally57:
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->enumerator);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		__g_list_free__g_object_unref0_0 (_data_->list);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1714 "media-manager.c"
	}
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->list;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->enumerator);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1724 "media-manager.c"
	} else {
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1728 "media-manager.c"
	}
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->enumerator);
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	__g_list_free__g_object_unref0_0 (_data_->list);
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1742 "media-manager.c"
	} else {
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1746 "media-manager.c"
	}
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 1752 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error) {
	BoxesInstallerMedia* result = NULL;
	BoxesInstallerMedia* _tmp0_;
	OsinfoOs* _tmp1_;
	BoxesInstallerMedia* _tmp4_;
	OsinfoOs* _tmp5_;
	OsinfoInstallScriptList* _tmp6_ = NULL;
	OsinfoInstallScriptList* install_scripts;
	OsinfoFilter* _tmp7_;
	OsinfoFilter* filter;
	OsinfoFilter* _tmp8_;
	OsinfoInstallScriptList* _tmp9_;
	OsinfoFilter* _tmp10_;
	OsinfoList* _tmp11_ = NULL;
	OsinfoInstallScriptList* _tmp12_;
	BoxesInstallerMedia* install_media = NULL;
	OsinfoInstallScriptList* _tmp13_;
	gint _tmp14_ = 0;
	GError * _inner_error_ = NULL;
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = media;
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _tmp0_->os;
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_tmp1_ == NULL) {
#line 1785 "media-manager.c"
		BoxesInstallerMedia* _tmp2_;
		BoxesInstallerMedia* _tmp3_;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp2_ = media;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		result = _tmp3_;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return result;
#line 1796 "media-manager.c"
	}
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp4_ = media;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp5_ = _tmp4_->os;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp6_ = osinfo_os_get_install_script_list (_tmp5_);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	install_scripts = _tmp6_;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp7_ = osinfo_filter_new ();
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	filter = _tmp7_;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp8_ = filter;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	osinfo_filter_add_constraint (_tmp8_, OSINFO_INSTALL_SCRIPT_PROP_PROFILE, OSINFO_INSTALL_SCRIPT_PROFILE_DESKTOP);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp9_ = install_scripts;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp10_ = filter;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp11_ = osinfo_list_new_filtered (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp9_) : NULL, _tmp10_);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, osinfo_install_scriptlist_get_type ()) ? ((OsinfoInstallScriptList*) _tmp11_) : NULL;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_tmp12_ == NULL) {
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_tmp11_);
#line 1826 "media-manager.c"
	}
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (install_scripts);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	install_scripts = _tmp12_;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp13_ = install_scripts;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp14_ = osinfo_list_get_length ((OsinfoList*) _tmp13_);
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_tmp14_ > 0) {
#line 1838 "media-manager.c"
		BoxesInstallerMedia* _tmp15_;
		OsinfoInstallScriptList* _tmp16_;
		BoxesUnattendedInstaller* _tmp17_;
		BoxesUnattendedInstaller* _tmp18_;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp15_ = media;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp16_ = install_scripts;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp17_ = boxes_unattended_installer_new_from_media (_tmp15_, _tmp16_, &_inner_error_);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp18_ = _tmp17_;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_inner_error_ != NULL) {
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_propagate_error (error, _inner_error_);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_media);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (filter);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_scripts);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			return NULL;
#line 1863 "media-manager.c"
		}
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (install_media);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		install_media = (BoxesInstallerMedia*) _tmp18_;
#line 1869 "media-manager.c"
	} else {
		BoxesInstallerMedia* _tmp19_;
		BoxesInstallerMedia* _tmp20_;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp19_ = media;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp20_ = _g_object_ref0 (_tmp19_);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (install_media);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		install_media = _tmp20_;
#line 1881 "media-manager.c"
	}
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = install_media;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (filter);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (install_scripts);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 1891 "media-manager.c"
}


static BoxesMediaManager* boxes_media_manager_construct (GType object_type) {
	BoxesMediaManager * self = NULL;
	gchar* _tmp0_;
	gchar** _tmp1_ = NULL;
	gchar** _tmp2_;
	gint _tmp2__length1;
	GUdevClient* _tmp3_;
	GUdevClient* _tmp4_;
	BoxesOSDatabase* _tmp5_;
	BoxesOSDatabase* _tmp6_;
	BoxesOSDatabase* _tmp7_;
	GError * _inner_error_ = NULL;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	self = (BoxesMediaManager*) g_object_new (object_type, NULL);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = g_strdup ("block");
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = g_new0 (gchar*, 1 + 1);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_[0] = _tmp0_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _tmp1_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2__length1 = 1;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp3_ = g_udev_client_new (_tmp2_);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _tmp3_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_set_client (self, _tmp4_);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_tmp4_);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = (_vala_array_free (_tmp2_, _tmp2__length1, (GDestroyNotify) g_free), NULL);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp5_ = boxes_os_database_new ();
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp6_ = _tmp5_;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_set_os_db (self, _tmp6_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_tmp6_);
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp7_ = self->priv->_os_db;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_os_database_load (_tmp7_, NULL, NULL);
#line 1941 "media-manager.c"
	{
		TrackerSparqlConnection* _tmp8_ = NULL;
		TrackerSparqlConnection* _tmp9_;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp8_ = tracker_sparql_connection_get (NULL, &_inner_error_);
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp9_ = _tmp8_;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_inner_error_ != NULL) {
#line 1951 "media-manager.c"
			goto __catch59_g_error;
		}
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (self->priv->connection);
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		self->priv->connection = _tmp9_;
#line 1958 "media-manager.c"
	}
	goto __finally59;
	__catch59_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp10_;
		const gchar* _tmp11_;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_error_ = _inner_error_;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_inner_error_ = NULL;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp10_ = _error_;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_tmp11_ = _tmp10_->message;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_critical ("media-manager.vala:149: Error connecting to Tracker: %s", _tmp11_);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_error_);
#line 1978 "media-manager.c"
	}
	__finally59:
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_inner_error_ != NULL) {
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_inner_error_);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 1989 "media-manager.c"
	}
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return self;
#line 1993 "media-manager.c"
}


static BoxesMediaManager* boxes_media_manager_new (void) {
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return boxes_media_manager_construct (BOXES_TYPE_MEDIA_MANAGER);
#line 2000 "media-manager.c"
}


static gint boxes_media_manager_compare_media (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b) {
	gint result = 0;
	GCompareFunc _tmp0_;
	BoxesInstallerMedia* _tmp1_;
	const gchar* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	const gchar* _tmp4_;
	gint _tmp5_ = 0;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_a != NULL, 0);
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_b != NULL, 0);
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = g_strcmp0;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = media_a;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _tmp1_->label;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp3_ = media_b;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _tmp3_->label;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp5_ = _tmp0_ (_tmp2_, _tmp4_);
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _tmp5_;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 2032 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
	_data_ = _data;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->os_id);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->media_id);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData, _data_);
#line 2053 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info (BoxesMediaManager* self, const gchar* path, const gchar* label, const gchar* os_id, const gchar* media_id, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
	BoxesMediaManager* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_from_iso_info);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_from_iso_info_data_free);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = path;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->path = _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp3_ = label;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->label = _tmp4_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp5_ = os_id;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->os_id);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->os_id = _tmp6_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp7_ = media_id;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->media_id);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->media_id = _tmp8_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_iso_info_co (_data_);
#line 2112 "media-manager.c"
}


static BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_iso_info_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 2123 "media-manager.c"
	}
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 2133 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_iso_info_co (_data_);
#line 2147 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_from_iso_info_co (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_) {
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 0:
#line 2156 "media-manager.c"
		goto _state_0;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 1:
#line 2160 "media-manager.c"
		goto _state_1;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case 2:
#line 2164 "media-manager.c"
		goto _state_2;
		default:
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 2169 "media-manager.c"
	}
	_state_0:
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->path;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = FALSE;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = g_file_test (_data_->_tmp0_, G_FILE_TEST_EXISTS);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (!_data_->_tmp1_) {
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = NULL;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = _ ("No such file %s");
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = _data_->path;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = NULL;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = g_strdup_printf (_data_->_tmp2_, _data_->_tmp3_);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _data_->_tmp5_);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp5_);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = _data_->_tmp7_;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2208 "media-manager.c"
		} else {
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2212 "media-manager.c"
		}
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2218 "media-manager.c"
	}
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = _data_->label;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp10_ == NULL) {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = TRUE;
#line 2226 "media-manager.c"
	} else {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp11_ = _data_->os_id;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = _data_->_tmp11_ == NULL;
#line 2232 "media-manager.c"
	}
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = _data_->_tmp9_;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp12_) {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = TRUE;
#line 2240 "media-manager.c"
	} else {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp13_ = _data_->media_id;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = _data_->_tmp13_ == NULL;
#line 2246 "media-manager.c"
	}
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp14_ = _data_->_tmp8_;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp14_) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp15_ = _data_->path;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 1;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_create_installer_media_for_path (_data_->self, _data_->_tmp15_, NULL, boxes_media_manager_create_installer_media_from_iso_info_ready, _data_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2260 "media-manager.c"
		_state_1:
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = NULL;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = boxes_media_manager_create_installer_media_for_path_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = _data_->_tmp16_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_error_free (_data_->_inner_error_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2278 "media-manager.c"
			} else {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2282 "media-manager.c"
			}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 2288 "media-manager.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_data_->result = _data_->_tmp17_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2296 "media-manager.c"
		} else {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2300 "media-manager.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2306 "media-manager.c"
	}
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp18_ = _data_->self->priv->_os_db;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = _data_->os_id;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_state_ = 2;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_os_database_get_os_by_id (_data_->_tmp18_, _data_->_tmp19_, boxes_media_manager_create_installer_media_from_iso_info_ready, _data_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 2318 "media-manager.c"
	_state_2:
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = NULL;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp18_, _data_->_res_, &_data_->_inner_error_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->os = _data_->_tmp20_;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2336 "media-manager.c"
		} else {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2340 "media-manager.c"
		}
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2346 "media-manager.c"
	}
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = _data_->self->priv->_os_db;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = _data_->os;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp23_ = _data_->media_id;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp24_ = NULL;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp24_ = boxes_os_database_get_media_by_id (_data_->_tmp21_, _data_->_tmp22_, _data_->_tmp23_, &_data_->_inner_error_);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->os_media = _data_->_tmp24_;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2372 "media-manager.c"
		} else {
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2376 "media-manager.c"
		}
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2382 "media-manager.c"
	}
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp25_ = _data_->self->priv->_os_db;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26_ = _data_->os;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp27_ = _data_->os_media;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp28_ = NULL;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_get (_data_->_tmp27_, "architecture", &_data_->_tmp28_, NULL);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = NULL;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = boxes_os_database_get_resources_for_os (_data_->_tmp25_, _data_->_tmp26_, _data_->_tmp30_);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp30_);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->resources = _data_->_tmp32_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp33_ = _data_->path;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = _data_->label;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp35_ = _data_->os;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = _data_->os_media;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = _data_->resources;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = boxes_installer_media_new_from_iso_info (_data_->_tmp33_, _data_->_tmp34_, _data_->_tmp35_, _data_->_tmp36_, _data_->_tmp37_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp38_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = _data_->media;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = NULL;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp39_, &_data_->_inner_error_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = _data_->_tmp40_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->resources);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2448 "media-manager.c"
		} else {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2452 "media-manager.c"
		}
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2458 "media-manager.c"
	}
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->_tmp41_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2474 "media-manager.c"
	} else {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2478 "media-manager.c"
	}
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2496 "media-manager.c"
	} else {
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2500 "media-manager.c"
	}
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 2506 "media-manager.c"
}


BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self) {
	BoxesOSDatabase* result;
	BoxesOSDatabase* _tmp0_;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = self->priv->_os_db;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _tmp0_;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 2521 "media-manager.c"
}


static void boxes_media_manager_set_os_db (BoxesMediaManager* self, BoxesOSDatabase* value) {
	BoxesOSDatabase* _tmp0_;
	BoxesOSDatabase* _tmp1_;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_if_fail (self != NULL);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = value;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_os_db);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	self->priv->_os_db = _tmp1_;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_notify ((GObject *) self, "os-db");
#line 2540 "media-manager.c"
}


GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self) {
	GUdevClient* result;
	GUdevClient* _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = self->priv->_client;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	result = _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	return result;
#line 2555 "media-manager.c"
}


static void boxes_media_manager_set_client (BoxesMediaManager* self, GUdevClient* value) {
	GUdevClient* _tmp0_;
	GUdevClient* _tmp1_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp0_ = value;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_client);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	self->priv->_client = _tmp1_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_notify ((GObject *) self, "client");
#line 2574 "media-manager.c"
}


static void boxes_media_manager_class_init (BoxesMediaManagerClass * klass) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_type_class_add_private (klass, sizeof (BoxesMediaManagerPrivate));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_media_manager_get_property;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_media_manager_set_property;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_media_manager_finalize;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MEDIA_MANAGER_OS_DB, g_param_spec_object ("os-db", "os-db", "os-db", BOXES_TYPE_OS_DATABASE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MEDIA_MANAGER_CLIENT, g_param_spec_object ("client", "client", "client", g_udev_client_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 2593 "media-manager.c"
}


static void boxes_media_manager_instance_init (BoxesMediaManager * self) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	self->priv = BOXES_MEDIA_MANAGER_GET_PRIVATE (self);
#line 2600 "media-manager.c"
}


static void boxes_media_manager_finalize (GObject* obj) {
	BoxesMediaManager * self;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_os_db);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_client);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->connection);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (boxes_media_manager_parent_class)->finalize (obj);
#line 2616 "media-manager.c"
}


GType boxes_media_manager_get_type (void) {
	static volatile gsize boxes_media_manager_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_media_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMediaManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_media_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMediaManager), 0, (GInstanceInitFunc) boxes_media_manager_instance_init, NULL };
		GType boxes_media_manager_type_id;
		boxes_media_manager_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesMediaManager", &g_define_type_info, 0);
		g_once_init_leave (&boxes_media_manager_type_id__volatile, boxes_media_manager_type_id);
	}
	return boxes_media_manager_type_id__volatile;
}


static void _vala_boxes_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	switch (property_id) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_OS_DB:
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_value_set_object (value, boxes_media_manager_get_os_db (self));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		break;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_CLIENT:
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		g_value_set_object (value, boxes_media_manager_get_client (self));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		break;
#line 2649 "media-manager.c"
		default:
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		break;
#line 2655 "media-manager.c"
	}
}


static void _vala_boxes_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
	switch (property_id) {
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_OS_DB:
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_set_os_db (self, g_value_get_object (value));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		break;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_CLIENT:
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_set_client (self, g_value_get_object (value));
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		break;
#line 2677 "media-manager.c"
		default:
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/media-manager.vala"
		break;
#line 2683 "media-manager.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 2691 "media-manager.c"
		int i;
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 2699 "media-manager.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 2711 "media-manager.c"
}



